# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Monitoring(_OCI):
    _type = "monitoring"
    _icon_dir = "resources/oci/monitoring"


class AlarmGrey(_Monitoring):
    _icon = "alarm-grey.png"


class Alarm(_Monitoring):
    _icon = "alarm.png"


class EventGrey(_Monitoring):
    _icon = "event-grey.png"


class Event(_Monitoring):
    _icon = "event.png"


class HealthcheckGrey(_Monitoring):
    _icon = "healthcheck-grey.png"


class Healthcheck(_Monitoring):
    _icon = "healthcheck.png"


class LoggingGrey(_Monitoring):
    _icon = "logging-grey.png"


class Logging(_Monitoring):
    _icon = "logging.png"


class NotificationsGrey(_Monitoring):
    _icon = "notifications-grey.png"


class Notifications(_Monitoring):
    _icon = "notifications.png"


class QueuingGrey(_Monitoring):
    _icon = "queuing-grey.png"


class Queuing(_Monitoring):
    _icon = "queuing.png"


class SearchGrey(_Monitoring):
    _icon = "search-grey.png"


class Search(_Monitoring):
    _icon = "search.png"


class StreamingGrey(_Monitoring):
    _icon = "streaming-grey.png"


class Streaming(_Monitoring):
    _icon = "streaming.png"


class TelemetryGrey(_Monitoring):
    _icon = "telemetry-grey.png"


class Telemetry(_Monitoring):
    _icon = "telemetry.png"


class WorkflowGrey(_Monitoring):
    _icon = "workflow-grey.png"


class Workflow(_Monitoring):
    _icon = "workflow.png"


# Aliases
