# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Monitoring(_OnPrem):
    _type = "monitoring"
    _icon_dir = "resources/onprem/monitoring"


class Datadog(_Monitoring):
    _icon = "datadog.png"


class Grafana(_Monitoring):
    _icon = "grafana.png"


class Kibana(_Monitoring):
    _icon = "kibana.png"


class Prometheus(_Monitoring):
    _icon = "prometheus.png"


class Sentry(_Monitoring):
    _icon = "sentry.png"


class Splunk(_Monitoring):
    _icon = "splunk.png"


class Thanos(_Monitoring):
    _icon = "thanos.png"


# Aliases
