print("import: 'diagrams'")
import diagrams

print("import: 'diagrams.alibabacloud'")
import diagrams.alibabacloud

print("import: 'diagrams.aws'")
import diagrams.aws

print("import: 'diagrams.azure'")
import diagrams.azure

print("import: 'diagrams.base'")
import diagrams.base

print("import: 'diagrams.custom'")
import diagrams.custom

print("import: 'diagrams.gcp'")
import diagrams.gcp

print("import: 'diagrams.k8s'")
import diagrams.k8s

print("import: 'diagrams.oci'")
import diagrams.oci

print("import: 'diagrams.onprem'")
import diagrams.onprem

