# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Database(_OCI):
    _type = "database"
    _icon_dir = "resources/oci/database"


class DatabaseserviceGrey(_Database):
    _icon = "databaseservice-grey.png"


class Databaseservice(_Database):
    _icon = "databaseservice.png"


# Aliases

DBService = Databaseservice
DBServiceGrey = DatabaseserviceGrey
