# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Compute(_OCI):
    _type = "compute"
    _icon_dir = "resources/oci/compute"


class BmGrey(_Compute):
    _icon = "bm-grey.png"


class Bm(_Compute):
    _icon = "bm.png"


class ContainerGrey(_Compute):
    _icon = "container-grey.png"


class Container(_Compute):
    _icon = "container.png"


class VmGrey(_Compute):
    _icon = "vm-grey.png"


class Vm(_Compute):
    _icon = "vm.png"


# Aliases

VirtualMachine = Vm
VirtualMachineGrey = VmGrey
BareMetal = Bm
BareMetalGrey = BmGrey
