# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Edge(_OCI):
    _type = "edge"
    _icon_dir = "resources/oci/edge"


class CdnGrey(_Edge):
    _icon = "cdn-grey.png"


class Cdn(_Edge):
    _icon = "cdn.png"


class DnsGrey(_Edge):
    _icon = "dns-grey.png"


class Dns(_Edge):
    _icon = "dns.png"


class EmaildeliveryGrey(_Edge):
    _icon = "emaildelivery-grey.png"


class Emaildelivery(_Edge):
    _icon = "emaildelivery.png"


class WafGrey(_Edge):
    _icon = "waf-grey.png"


class Waf(_Edge):
    _icon = "waf.png"


# Aliases
